#[repr(i32)]pub enum ContainerEventType {
ContainerCreatedEvent = 0,
ContainerStartedEvent = 1,
ContainerStoppedEvent = 2,
ContainerDeletedEvent = 3,
}Variants
ContainerCreatedEvent = 0
Container created
ContainerStartedEvent = 1
Container started
ContainerStoppedEvent = 2
Container stopped
ContainerDeletedEvent = 3
Container deleted
Implementations
Sourceimpl ContainerEventType
impl ContainerEventType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.