#[repr(i32)]pub enum MountPropagation {
PropagationPrivate = 0,
PropagationHostToContainer = 1,
PropagationBidirectional = 2,
}Variants
PropagationPrivate = 0
No mount propagation (“private” in Linux terminology).
PropagationHostToContainer = 1
Mounts get propagated from the host to the container (“rslave” in Linux).
PropagationBidirectional = 2
Mounts get propagated from the host to the container and from the container to the host (“rshared” in Linux).
Implementations
Sourceimpl MountPropagation
impl MountPropagation
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.