NamespaceMode

Enum NamespaceMode 

#[repr(i32)]
pub enum NamespaceMode { Pod = 0, Container = 1, Node = 2, Target = 3, }
A NamespaceMode describes the intended namespace configuration for each of the namespaces (Network, PID, IPC) in NamespaceOption. Runtimes should map these modes as appropriate for the technology underlying the runtime.

Variants



Pod = 0

A POD namespace is common to all containers in a pod. For example, a container with a PID namespace of POD expects to view all of the processes in all of the containers in the pod.



Container = 1

A CONTAINER namespace is restricted to a single container. For example, a container with a PID namespace of CONTAINER expects to view only the processes in that container.



Node = 2

A NODE namespace is the namespace of the Kubernetes node. For example, a container with a PID namespace of NODE expects to view all of the processes on the host running the kubelet.



Target = 3

TARGET targets the namespace of another container. When this is specified, a target_id must be specified in NamespaceOption and refer to a container previously created with NamespaceMode CONTAINER. This containers namespace will be made to match that of container target_id. For example, a container with a PID namespace of TARGET expects to view all of the processes that container target_id can view.

Implementations

Source

impl NamespaceMode

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of NamespaceMode.

pub fn from_i32(value: i32) -> Option<NamespaceMode>

👎Deprecated: Use the TryFrom<i32> implementation instead

Converts an i32 to a NamespaceMode, or None if value is not a valid variant.

Source

impl NamespaceMode

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<Self>

Creates an enum from field names used in the ProtoBuf definition.