#[repr(i32)]pub enum ProfileType {
RuntimeDefault = 0,
Unconfined = 1,
Localhost = 2,
}Expand description
Available profile types.
Variants
RuntimeDefault = 0
The container runtime default profile should be used.
Unconfined = 1
Disable the feature for the sandbox or the container.
Localhost = 2
A pre-defined profile on the node should be used.
Implementations
Sourceimpl ProfileType
impl ProfileType
Sourceimpl ProfileType
impl ProfileType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.