pub struct AttachRequest {
pub container_id: String,
pub stdin: bool,
pub tty: bool,
pub stdout: bool,
pub stderr: bool,
}Fields
container_id: StringID of the container to which to attach.
stdin: boolWhether to stream stdin.
One of stdin, stdout, and stderr MUST be true.
tty: boolWhether the process being attached is running in a TTY. This must match the TTY setting in the ContainerConfig.
stdout: boolWhether to stream stdout.
One of stdin, stdout, and stderr MUST be true.
stderr: boolWhether to stream stderr.
One of stdin, stdout, and stderr MUST be true.
If tty is true, stderr MUST be false. Multiplexing is not supported
in this case. The output of stdout and stderr will be combined to a
single stream.