pub struct AuthConfig {
pub username: String,
pub password: String,
pub auth: String,
pub server_address: String,
pub identity_token: String,
pub registry_token: String,
}Expand description
AuthConfig contains authorization information for connecting to a registry.
Fields
username: Stringpassword: Stringauth: Stringserver_address: Stringidentity_token: StringIdentityToken is used to authenticate the user and get an access token for the registry.
registry_token: StringRegistryToken is a bearer token to be sent to a registry