pub struct ContainerMetadata {
pub name: String,
pub attempt: u32,
}Expand description
ContainerMetadata holds all necessary information for building the container name. The container runtime is encouraged to expose the metadata in its user interface for better user experience. E.g., runtime can construct a unique container name based on the metadata. Note that (name, attempt) is unique within a sandbox for the entire lifetime of the sandbox.
Fields
name: StringName of the container. Same as the container name in the PodSpec.
attempt: u32Attempt number of creating the container. Default: 0.