pub struct ContainerStatusRequest {
pub container_id: String,
pub verbose: bool,
}Fields
container_id: StringID of the container for which to retrieve status.
verbose: boolVerbose indicates whether to return extra information about the container.