pub struct CreateContainerRequest {
pub pod_sandbox_id: String,
pub config: Option<ContainerConfig>,
pub sandbox_config: Option<PodSandboxConfig>,
}Fields
pod_sandbox_id: StringID of the PodSandbox in which the container should be created.
config: Option<ContainerConfig>Config of the container.
sandbox_config: Option<PodSandboxConfig>Config of the PodSandbox. This is the same config that was passed to RunPodSandboxRequest to create the PodSandbox. It is passed again here just for easy reference. The PodSandboxConfig is immutable and remains the same throughout the lifetime of the pod.