pub struct ExecRequest {
pub container_id: String,
pub cmd: Vec<String>,
pub tty: bool,
pub stdin: bool,
pub stdout: bool,
pub stderr: bool,
}Fields
container_id: StringID of the container in which to execute the command.
cmd: Vec<String>Command to execute.
tty: boolWhether to exec the command in a TTY.
stdin: boolWhether to stream stdin.
One of stdin, stdout, and stderr MUST be true.
stdout: boolWhether to stream stdout.
One of stdin, stdout, and stderr MUST be true.
stderr: boolWhether to stream stderr.
One of stdin, stdout, and stderr MUST be true.
If tty is true, stderr MUST be false. Multiplexing is not supported
in this case. The output of stdout and stderr will be combined to a
single stream.