LinuxSandboxSecurityContext

Struct LinuxSandboxSecurityContext 

pub struct LinuxSandboxSecurityContext {
    pub namespace_options: Option<NamespaceOption>,
    pub selinux_options: Option<SeLinuxOption>,
    pub run_as_user: Option<Int64Value>,
    pub run_as_group: Option<Int64Value>,
    pub readonly_rootfs: bool,
    pub supplemental_groups: Vec<i64>,
    pub privileged: bool,
    pub seccomp: Option<SecurityProfile>,
    pub apparmor: Option<SecurityProfile>,
    pub seccomp_profile_path: String,
}
LinuxSandboxSecurityContext holds linux security configuration that will be applied to a sandbox. Note that:

  1. It does not apply to containers in the pods.
  2. It may not be applicable to a PodSandbox which does not contain any running process.

Fields

namespace_options: Option<NamespaceOption>

Configurations for the sandbox’s namespaces. This will be used only if the PodSandbox uses namespace for isolation.

selinux_options: Option<SeLinuxOption>

Optional SELinux context to be applied.

run_as_user: Option<Int64Value>

UID to run sandbox processes as, when applicable.

run_as_group: Option<Int64Value>

GID to run sandbox processes as, when applicable. run_as_group should only be specified when run_as_user is specified; otherwise, the runtime MUST error.

readonly_rootfs: bool

If set, the root filesystem of the sandbox is read-only.

supplemental_groups: Vec<i64>

List of groups applied to the first process run in the sandbox, in addition to the sandbox’s primary GID.

privileged: bool

Indicates whether the sandbox will be asked to run a privileged container. If a privileged container is to be executed within it, this MUST be true. This allows a sandbox to take additional security precautions if no privileged containers are expected to be run.

seccomp: Option<SecurityProfile>

Seccomp profile for the sandbox.

apparmor: Option<SecurityProfile>

AppArmor profile for the sandbox.

seccomp_profile_path: String
👎Deprecated

Seccomp profile for the sandbox, candidate values are:

  • runtime/default: the default profile for the container runtime
  • unconfined: unconfined profile, ie, no seccomp sandboxing
  • localhost/: the profile installed on the node. is the full path of the profile. Default: “”, which is identical with unconfined.