pub struct Mount {
pub container_path: String,
pub host_path: String,
pub readonly: bool,
pub selinux_relabel: bool,
pub propagation: i32,
}Expand description
Mount specifies a host volume to mount into a container.
Fields
container_path: StringPath of the mount within the container.
host_path: StringPath of the mount on the host. If the hostPath doesn’t exist, then runtimes should report error. If the hostpath is a symbolic link, runtimes should follow the symlink and mount the real destination to container.
readonly: boolIf set, the mount is read-only.
selinux_relabel: boolIf set, the mount needs SELinux relabeling.
propagation: i32Requested propagation mode.
Implementations
Sourceimpl Mount
impl Mount
Sourcepub fn propagation(&self) -> MountPropagation
pub fn propagation(&self) -> MountPropagation
Returns the enum value of propagation, or the default if the field is set to an invalid enum value.
Sourcepub fn set_propagation(&mut self, value: MountPropagation)
pub fn set_propagation(&mut self, value: MountPropagation)
Sets propagation to the provided enum value.