pub struct PodSandboxFilter {
pub id: String,
pub state: Option<PodSandboxStateValue>,
pub label_selector: HashMap<String, String>,
}Expand description
PodSandboxFilter is used to filter a list of PodSandboxes. All those fields are combined with ‘AND’
Fields
id: StringID of the sandbox.
state: Option<PodSandboxStateValue>State of the sandbox.
label_selector: HashMap<String, String>LabelSelector to select matches. Only api.MatchLabels is supported for now and the requirements are ANDed. MatchExpressions is not supported yet.