PodSandboxMetadata

Struct PodSandboxMetadata 

pub struct PodSandboxMetadata {
    pub name: String,
    pub uid: String,
    pub namespace: String,
    pub attempt: u32,
}
PodSandboxMetadata holds all necessary information for building the sandbox name. The container runtime is encouraged to expose the metadata associated with the PodSandbox in its user interface for better user experience. For example, the runtime can construct a unique PodSandboxName based on the metadata.

Fields

name: String

Pod name of the sandbox. Same as the pod name in the Pod ObjectMeta.

uid: String

Pod UID of the sandbox. Same as the pod UID in the Pod ObjectMeta.

namespace: String

Pod namespace of the sandbox. Same as the pod namespace in the Pod ObjectMeta.

attempt: u32

Attempt number of creating the sandbox. Default: 0.