pub struct PodSandboxNetworkStatus {
pub ip: String,
pub additional_ips: Vec<PodIp>,
}Expand description
PodSandboxNetworkStatus is the status of the network for a PodSandbox. Currently ignored for pods sharing the host networking namespace.
Fields
ip: StringIP address of the PodSandbox.
additional_ips: Vec<PodIp>list of additional ips (not inclusive of PodSandboxNetworkStatus.Ip) of the PodSandBoxNetworkStatus