pub struct PodSandboxStatsFilter {
pub id: String,
pub label_selector: HashMap<String, String>,
}Expand description
PodSandboxStatsFilter is used to filter the list of pod sandboxes to retrieve stats for. All those fields are combined with ‘AND’.
Fields
id: StringID of the pod sandbox.
label_selector: HashMap<String, String>LabelSelector to select matches. Only api.MatchLabels is supported for now and the requirements are ANDed. MatchExpressions is not supported yet.