pub struct PodSandboxStatusResponse {
pub status: Option<PodSandboxStatus>,
pub info: HashMap<String, String>,
}Fields
status: Option<PodSandboxStatus>Status of the PodSandbox.
info: HashMap<String, String>Info is extra information of the PodSandbox. The key could be arbitrary string, and value should be in json format. The information could include anything useful for debug, e.g. network namespace for linux container based container runtime. It should only be returned non-empty when Verbose is true.