pub struct RunPodSandboxRequest {
pub config: Option<PodSandboxConfig>,
pub runtime_handler: String,
}Fields
config: Option<PodSandboxConfig>Configuration for creating a PodSandbox.
runtime_handler: StringNamed runtime configuration to use for this PodSandbox. If the runtime handler is unknown, this request should be rejected. An empty string should select the default handler, equivalent to the behavior before this feature was added. See https://git.k8s.io/enhancements/keps/sig-node/585-runtime-class