pub struct WindowsContainerResources {
pub cpu_shares: i64,
pub cpu_count: i64,
pub cpu_maximum: i64,
pub memory_limit_in_bytes: i64,
pub rootfs_size_in_bytes: i64,
}Expand description
WindowsContainerResources specifies Windows specific configuration for resources.
Fields
CPU shares (relative weight vs. other containers). Default: 0 (not specified).
cpu_count: i64Number of CPUs available to the container. Default: 0 (not specified).
cpu_maximum: i64Specifies the portion of processor cycles that this container can use as a percentage times 100.
memory_limit_in_bytes: i64Memory limit in bytes. Default: 0 (not specified).
rootfs_size_in_bytes: i64Specifies the size of the rootfs / scratch space in bytes to be configured for this container. Default: 0 (not specified).