pub struct WindowsContainerSecurityContext {
pub run_as_username: String,
pub credential_spec: String,
pub host_process: bool,
}Expand description
WindowsContainerSecurityContext holds windows security configuration that will be applied to a container.
Fields
run_as_username: StringUser name to run the container process as. If specified, the user MUST exist in the container image and be resolved there by the runtime; otherwise, the runtime MUST return error.
credential_spec: StringThe contents of the GMSA credential spec to use to run this container.
host_process: boolIndicates whether a container is to be run as a HostProcess container.