Copyright (2024, ) Institute of Software, Chinese Academy of Sciences since 0.1.1 API version v1, original Protocol Buffers file.
Modules
- image_
service_ client - Generated client implementations.
- image_
service_ server - Generated server implementations.
- runtime_
service_ client - Generated client implementations.
- runtime_
service_ server - Generated server implementations.
- security_
profile - Nested message and enum types in
SecurityProfile.
Structs
- Attach
Request - Attach
Response - Auth
Config - AuthConfig contains authorization information for connecting to a registry.
- Capability
- Capability contains the container capabilities to add or drop Dropping a capability will drop it from all sets. If a capability is added to only the add_capabilities list then it gets added to permitted, inheritable, effective and bounding sets, i.e. all sets except the ambient set. If a capability is added to only the add_ambient_capabilities list then it gets added to all sets, i.e permitted inheritable, effective, bounding and ambient sets. If a capability is added to add_capabilities and add_ambient_capabilities lists then it gets added to all sets, i.e. permitted, inheritable, effective, bounding and ambient sets.
- Checkpoint
Container Request - Checkpoint
Container Response - Container
- Container provides the runtime information for a container, such as ID, hash, state of the container.
- Container
Attributes - ContainerAttributes provides basic information of the container.
- Container
Config - ContainerConfig holds all the required and optional fields for creating a container.
- Container
Event Response - Container
Filter - ContainerFilter is used to filter containers. All those fields are combined with ‘AND’
- Container
Metadata - ContainerMetadata holds all necessary information for building the container name. The container runtime is encouraged to expose the metadata in its user interface for better user experience. E.g., runtime can construct a unique container name based on the metadata. Note that (name, attempt) is unique within a sandbox for the entire lifetime of the sandbox.
- Container
Resources - ContainerResources holds resource limits configuration for a container.
- Container
State Value - ContainerStateValue is the wrapper of ContainerState.
- Container
Stats - ContainerStats provides the resource usage statistics for a container.
- Container
Stats Filter - ContainerStatsFilter is used to filter containers. All those fields are combined with ‘AND’
- Container
Stats Request - Container
Stats Response - Container
Status - ContainerStatus represents the status of a container.
- Container
Status Request - Container
Status Response - CpuUsage
- CpuUsage provides the CPU usage information.
- Create
Container Request - Create
Container Response - Device
- Device specifies a host device to mount into a container.
- DnsConfig
- DNSConfig specifies the DNS servers and search domains of a sandbox.
- Exec
Request - Exec
Response - Exec
Sync Request - Exec
Sync Response - Filesystem
Identifier - FilesystemIdentifier uniquely identify the filesystem.
- Filesystem
Usage - FilesystemUsage provides the filesystem usage information.
- GetEvents
Request - Hugepage
Limit - HugepageLimit corresponds to the file
hugetlb.<hugepagesize>.limit_in_bytein container level cgroup. For example,PageSize=1GB,Limit=1073741824means setting1073741824bytes to hugetlb.1GB.limit_in_bytes. - IdMapping
- IDMapping describes host to container ID mappings for a pod sandbox.
- Image
- Basic information about a container image.
- Image
Filter - Image
FsInfo Request - Image
FsInfo Response - Image
Spec - ImageSpec is an internal representation of an image.
- Image
Status Request - Image
Status Response - Int64
Value - Int64Value is the wrapper of int64.
- KeyValue
- Linux
Container Config - LinuxContainerConfig contains platform-specific configuration for Linux-based containers.
- Linux
Container Resources - LinuxContainerResources specifies Linux specific configuration for resources.
- Linux
Container Security Context - LinuxContainerSecurityContext holds linux security configuration that will be applied to a container.
- Linux
PodSandbox Config - LinuxPodSandboxConfig holds platform-specific configurations for Linux host platforms and Linux-based containers.
- Linux
PodSandbox Stats - LinuxPodSandboxStats provides the resource usage statistics for a pod sandbox on linux.
- Linux
PodSandbox Status - LinuxSandboxStatus contains status specific to Linux sandboxes.
- Linux
Sandbox Security Context - LinuxSandboxSecurityContext holds linux security configuration that will be applied to a sandbox. Note that:
- List
Container Stats Request - List
Container Stats Response - List
Containers Request - List
Containers Response - List
Images Request - List
Images Response - List
PodSandbox Request - List
PodSandbox Response - List
PodSandbox Stats Request - List
PodSandbox Stats Response - Memory
Usage - MemoryUsage provides the memory usage information.
- Mount
- Mount specifies a host volume to mount into a container.
- Namespace
- Namespace contains paths to the namespaces.
- Namespace
Option - NamespaceOption provides options for Linux namespaces.
- Network
Config - Network
Interface Usage - NetworkInterfaceUsage contains resource value data about a network interface.
- Network
Usage - NetworkUsage contains data about network resources.
- PodIp
- PodIP represents an ip of a Pod
- PodSandbox
- PodSandbox contains minimal information about a sandbox.
- PodSandbox
Attributes - PodSandboxAttributes provides basic information of the pod sandbox.
- PodSandbox
Config - PodSandboxConfig holds all the required and optional fields for creating a sandbox.
- PodSandbox
Filter - PodSandboxFilter is used to filter a list of PodSandboxes. All those fields are combined with ‘AND’
- PodSandbox
Metadata - PodSandboxMetadata holds all necessary information for building the sandbox name. The container runtime is encouraged to expose the metadata associated with the PodSandbox in its user interface for better user experience. For example, the runtime can construct a unique PodSandboxName based on the metadata.
- PodSandbox
Network Status - PodSandboxNetworkStatus is the status of the network for a PodSandbox. Currently ignored for pods sharing the host networking namespace.
- PodSandbox
State Value - PodSandboxStateValue is the wrapper of PodSandboxState.
- PodSandbox
Stats - PodSandboxStats provides the resource usage statistics for a pod. The linux or windows field will be populated depending on the platform.
- PodSandbox
Stats Filter - PodSandboxStatsFilter is used to filter the list of pod sandboxes to retrieve stats for. All those fields are combined with ‘AND’.
- PodSandbox
Stats Request - PodSandbox
Stats Response - PodSandbox
Status - PodSandboxStatus contains the status of the PodSandbox.
- PodSandbox
Status Request - PodSandbox
Status Response - Port
Forward Request - Port
Forward Response - Port
Mapping - PortMapping specifies the port mapping configurations of a sandbox.
- Process
Usage - ProcessUsage are stats pertaining to processes.
- Pull
Image Request - Pull
Image Response - Remove
Container Request - Remove
Container Response - Remove
Image Request - Remove
Image Response - Remove
PodSandbox Request - Remove
PodSandbox Response - Reopen
Container LogRequest - Reopen
Container LogResponse - RunPod
Sandbox Request - RunPod
Sandbox Response - Runtime
Condition - RuntimeCondition contains condition information for the runtime. There are 2 kinds of runtime conditions:
- Runtime
Config - Runtime
Status - RuntimeStatus is information about the current status of the runtime.
- SeLinux
Option - SELinuxOption are the labels to be applied to the container.
- Security
Profile - A security profile which can be used for sandboxes and containers.
- Start
Container Request - Start
Container Response - Status
Request - Status
Response - Stop
Container Request - Stop
Container Response - Stop
PodSandbox Request - Stop
PodSandbox Response - UInt64
Value - UInt64Value is the wrapper of uint64.
- Update
Container Resources Request - Update
Container Resources Response - Update
Runtime Config Request - Update
Runtime Config Response - User
Namespace - UserNamespace describes the intended user namespace configuration for a pod sandbox.
- Version
Request - Version
Response - Windows
Container Config - WindowsContainerConfig contains platform-specific configuration for Windows-based containers.
- Windows
Container Resources - WindowsContainerResources specifies Windows specific configuration for resources.
- Windows
Container Security Context - WindowsContainerSecurityContext holds windows security configuration that will be applied to a container.
- Windows
PodSandbox Config - WindowsPodSandboxConfig holds platform-specific configurations for Windows host platforms and Windows-based containers.
- Windows
PodSandbox Stats - WindowsPodSandboxStats provides the resource usage statistics for a pod sandbox on windows
- Windows
Sandbox Security Context - WindowsSandboxSecurityContext holds platform-specific configurations that will be applied to a sandbox. These settings will only apply to the sandbox container.
Enums
- Container
Event Type - Container
State - Mount
Propagation - Namespace
Mode - A NamespaceMode describes the intended namespace configuration for each of the namespaces (Network, PID, IPC) in NamespaceOption. Runtimes should map these modes as appropriate for the technology underlying the runtime.
- PodSandbox
State - Protocol