ContainerConfig

Struct ContainerConfig 

pub struct ContainerConfig {
Show 16 fields pub metadata: Option<ContainerMetadata>, pub image: Option<ImageSpec>, pub command: Vec<String>, pub args: Vec<String>, pub working_dir: String, pub envs: Vec<KeyValue>, pub mounts: Vec<Mount>, pub devices: Vec<Device>, pub labels: HashMap<String, String>, pub annotations: HashMap<String, String>, pub log_path: String, pub stdin: bool, pub stdin_once: bool, pub tty: bool, pub linux: Option<LinuxContainerConfig>, pub windows: Option<WindowsContainerConfig>,
}
ContainerConfig holds all the required and optional fields for creating a container.

Fields

metadata: Option<ContainerMetadata>

Metadata of the container. This information will uniquely identify the container, and the runtime should leverage this to ensure correct operation. The runtime may also use this information to improve UX, such as by constructing a readable name.

image: Option<ImageSpec>

Image to use.

command: Vec<String>

Command to execute (i.e., entrypoint for docker)

args: Vec<String>

Args for the Command (i.e., command for docker)

working_dir: String

Current working directory of the command.

envs: Vec<KeyValue>

List of environment variable to set in the container.

mounts: Vec<Mount>

Mounts for the container.

devices: Vec<Device>

Devices for the container.

labels: HashMap<String, String>

Key-value pairs that may be used to scope and select individual resources. Label keys are of the form: label-key ::= prefixed-name | name prefixed-name ::= prefix ‘/’ name prefix ::= DNS_SUBDOMAIN name ::= DNS_LABEL

annotations: HashMap<String, String>

Unstructured key-value map that may be used by the kubelet to store and retrieve arbitrary metadata.

Annotations MUST NOT be altered by the runtime; the annotations stored here MUST be returned in the ContainerStatus associated with the container this ContainerConfig creates.

In general, in order to preserve a well-defined interface between the kubelet and the container runtime, annotations SHOULD NOT influence runtime behaviour.

log_path: String

Path relative to PodSandboxConfig.LogDirectory for container to store the log (STDOUT and STDERR) on the host. E.g., PodSandboxConfig.LogDirectory = /var/log/pods/<podUID>/ ContainerConfig.LogPath = containerName/Instance#.log

WARNING: Log management and how kubelet should interface with the container logs are under active discussion in https://issues.k8s.io/24677. There may be future change of direction for logging as the discussion carries on.

stdin: bool

Variables for interactive containers, these have very specialized use-cases (e.g. debugging).

stdin_once: booltty: boollinux: Option<LinuxContainerConfig>

Configuration specific to Linux containers.

windows: Option<WindowsContainerConfig>

Configuration specific to Windows containers.