pub struct ContainerStatusResponse {
pub status: Option<ContainerStatus>,
pub info: HashMap<String, String>,
}Fields
status: Option<ContainerStatus>Status of the container.
info: HashMap<String, String>Info is extra information of the Container. The key could be arbitrary string, and value should be in json format. The information could include anything useful for debug, e.g. pid for linux container based container runtime. It should only be returned non-empty when Verbose is true.