pub struct Device {
pub container_path: String,
pub host_path: String,
pub permissions: String,
}Expand description
Device specifies a host device to mount into a container.
Fields
container_path: StringPath of the device within the container.
host_path: StringPath of the device on the host.
permissions: StringCgroups permissions of the device, candidates are one or more of
- r - allows container to read from the specified device.
- w - allows container to write to the specified device.
- m - allows container to create device files that do not yet exist.