pub struct FilesystemUsage {
pub timestamp: i64,
pub fs_id: Option<FilesystemIdentifier>,
pub used_bytes: Option<UInt64Value>,
pub inodes_used: Option<UInt64Value>,
}Expand description
FilesystemUsage provides the filesystem usage information.
Fields
timestamp: i64Timestamp in nanoseconds at which the information were collected. Must be > 0.
fs_id: Option<FilesystemIdentifier>The unique identifier of the filesystem.
used_bytes: Option<UInt64Value>UsedBytes represents the bytes used for images on the filesystem. This may differ from the total bytes used on the filesystem and may not equal CapacityBytes - AvailableBytes.
inodes_used: Option<UInt64Value>InodesUsed represents the inodes used by the images. This may not equal InodesCapacity - InodesAvailable because the underlying filesystem may also be used for purposes other than storing images.