NamespaceOption

Struct NamespaceOption 

pub struct NamespaceOption {
    pub network: i32,
    pub pid: i32,
    pub ipc: i32,
    pub target_id: String,
    pub userns_options: Option<UserNamespace>,
}
NamespaceOption provides options for Linux namespaces.

Fields

network: i32

Network namespace for this container/sandbox. Note: There is currently no way to set CONTAINER scoped network in the Kubernetes API. Namespaces currently set by the kubelet: POD, NODE

pid: i32

PID namespace for this container/sandbox. Note: The CRI default is POD, but the v1.PodSpec default is CONTAINER. The kubelet’s runtime manager will set this to CONTAINER explicitly for v1 pods. Namespaces currently set by the kubelet: POD, CONTAINER, NODE, TARGET

ipc: i32

IPC namespace for this container/sandbox. Note: There is currently no way to set CONTAINER scoped IPC in the Kubernetes API. Namespaces currently set by the kubelet: POD, NODE

target_id: String

Target Container ID for NamespaceMode of TARGET. This container must have been previously created in the same pod. It is not possible to specify different targets for each namespace.

userns_options: Option<UserNamespace>

UsernsOptions for this pod sandbox. The Kubelet picks the user namespace configuration to use for the pod sandbox. The mappings are specified as part of the UserNamespace struct. If the struct is nil, then the POD mode must be assumed. This is done for backward compatibility with older Kubelet versions that do not set a user namespace.

Implementations

Source

impl NamespaceOption

pub fn network(&self) -> NamespaceMode

Returns the enum value of network, or the default if the field is set to an invalid enum value.

pub fn set_network(&mut self, value: NamespaceMode)

Sets network to the provided enum value.

pub fn pid(&self) -> NamespaceMode

Returns the enum value of pid, or the default if the field is set to an invalid enum value.

pub fn set_pid(&mut self, value: NamespaceMode)

Sets pid to the provided enum value.

pub fn ipc(&self) -> NamespaceMode

Returns the enum value of ipc, or the default if the field is set to an invalid enum value.

pub fn set_ipc(&mut self, value: NamespaceMode)

Sets ipc to the provided enum value.