pub struct PodSandboxStateValue {
pub state: i32,
}Expand description
PodSandboxStateValue is the wrapper of PodSandboxState.
Fields
state: i32State of the sandbox.
Implementations
Sourceimpl PodSandboxStateValue
impl PodSandboxStateValue
Sourcepub fn state(&self) -> PodSandboxState
pub fn state(&self) -> PodSandboxState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: PodSandboxState)
pub fn set_state(&mut self, value: PodSandboxState)
Sets state to the provided enum value.