pub struct PodSandboxStats {
pub attributes: Option<PodSandboxAttributes>,
pub linux: Option<LinuxPodSandboxStats>,
pub windows: Option<WindowsPodSandboxStats>,
}Expand description
PodSandboxStats provides the resource usage statistics for a pod. The linux or windows field will be populated depending on the platform.
Fields
attributes: Option<PodSandboxAttributes>Information of the pod.
linux: Option<LinuxPodSandboxStats>Stats from linux.
windows: Option<WindowsPodSandboxStats>Stats from windows.