pub struct UpdateContainerResourcesRequest {
pub container_id: String,
pub linux: Option<LinuxContainerResources>,
pub windows: Option<WindowsContainerResources>,
pub annotations: HashMap<String, String>,
}Fields
container_id: StringID of the container to update.
linux: Option<LinuxContainerResources>Resource configuration specific to Linux containers.
windows: Option<WindowsContainerResources>Resource configuration specific to Windows containers.
annotations: HashMap<String, String>Unstructured key-value map holding arbitrary additional information for container resources updating. This can be used for specifying experimental resources to update or other options to use when updating the container.