pub struct UserNamespace {
pub mode: i32,
pub uids: Vec<IdMapping>,
pub gids: Vec<IdMapping>,
}Expand description
UserNamespace describes the intended user namespace configuration for a pod sandbox.
Fields
mode: i32Mode is the NamespaceMode for this UserNamespace. Note: NamespaceMode for UserNamespace currently supports only POD and NODE, not CONTAINER OR TARGET.
uids: Vec<IdMapping>Uids specifies the UID mappings for the user namespace.
gids: Vec<IdMapping>Gids specifies the GID mappings for the user namespace.
Implementations
Sourceimpl UserNamespace
impl UserNamespace
Sourcepub fn mode(&self) -> NamespaceMode
pub fn mode(&self) -> NamespaceMode
Returns the enum value of mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_mode(&mut self, value: NamespaceMode)
pub fn set_mode(&mut self, value: NamespaceMode)
Sets mode to the provided enum value.